@@ -1343,6 +1343,27 @@ def test_cover_conftest(testdir):
     result.stdout.fnmatch_lines([CONF_RESULT])
 
 
+def test_filterwarnings_error(testdir):
+    testdir.makeini(r"""
+    [pytest]
+    filterwarnings =
+        error
+    """)
+    testdir.makepyfile(mod=MODULE)
+    testdir.makepyfile(plug=CONFTEST)
+    script = testdir.makepyfile(BASIC_TEST)
+    result = testdir.runpytest('-v', '--cov=mod', '--cov-report=xml', '--cov-report=term-missing', '-p', 'plug', script)
+    assert result.ret == 0
+    result.stdout.fnmatch_lines(['* 1 passed *'])
+    result.stderr.fnmatch_lines(
+        [
+            '* (module-not-measured)',
+            '* (no-data-collected)',
+            '* CovReportWarning: Failed to generate report: No data to report.',
+        ]
+    )
+
+
 @pytest.mark.skipif('sys.platform == "win32" and platform.python_implementation() == "PyPy"')
 def test_cover_looponfail(testdir, monkeypatch):
     testdir.makepyfile(mod=MODULE)
@@ -1942,6 +1963,36 @@ def test_contexts_not_supported(testdir):
     assert result.ret != 0
 
 
+def test_contexts_no_cover(testdir):
+    script = testdir.makepyfile("""
+import pytest
+
+def foobar():
+    return 1
+
+def test_with_coverage():
+    foobar()
+
+@pytest.mark.no_cover()
+def test_without_coverage():
+    foobar()
+""")
+    result = testdir.runpytest(
+        '-v',
+        '--cov-context=test',
+        '--cov=test_contexts_no_cover',
+        script,
+    )
+    result.stdout.fnmatch_lines(
+        [
+            'test_contexts_no_cover.py       8      1    88%',
+            'TOTAL                           8      1    88%',
+        ]
+    )
+    assert result.stderr.lines == []
+    assert result.ret == 0
+
+
 def test_issue_417(testdir):
     # https://github.com/pytest-dev/pytest-cov/issues/417
     whatever = testdir.maketxtfile(whatever='')
